@@ -8,6 +8,9 @@ class ApiSettings(ApiBase):
     def cloud_accounts(self):
         return self.build_route("settings/cloudaccounts")
 
+    def compute_services(self):
+        return self.build_route("settings/cloudaccounts/computeservices")
+
     def status(self):
         return self.build_route("settings/status")
 
@@ -17,23 +20,12 @@ class ApiSettings(ApiBase):
     def aws_cloud_accounts(self):
         return self.build_route("settings/cloudaccounts/aws")
 
-    def aws_cloud_account_by_name(self, cloud_account_name: str):
-        return self.build_route(
-            "settings/cloudaccounts/aws/{cloud_account_name}".format(**locals())
-        )
-
-    def azure_cloud_account_by_name(self, cloud_account_name: str):
-        return self.build_route(
-            "settings/cloudaccounts/azure/{cloud_account_name}".format(**locals())
-        )
-
     def add_compute_service_aks(self):
         return self.build_route("settings/cloudaccounts/azure/computeservices/aks")
 
     def add_compute_service_aws_k8s_unmanaged(self):
         return self.build_route("settings/cloudaccounts/aws/computeservices/k8s_unmanaged")
 
-
     def aws_template(self):
         return self.build_route("settings/cloudaccounts/aws/template")
 
@@ -42,3 +34,6 @@ class ApiSettings(ApiBase):
 
     def account_roles(self):
         return self.build_route("settings/accountroles")
+
+    def verify_cloud_account(self):
+        return self.build_route("settings/cloudaccounts/verify")
